@@ -4,7 +4,7 @@ package Test::Base;
 use 5.006001;
 use Spiffy 0.30 -Base;
 use Spiffy ':XXX';
-our $VERSION = '0.57';
+our $VERSION = '0.58';
 
 my @test_more_exports;
 BEGIN {
@@ -619,7 +619,7 @@ sub run_filters {
                 my $old = $_;
                 @value = &$function(@value);
                 if (not(@value) or 
-                    @value == 1 and $value[0] =~ /\A(\d+|)\z/
+                    @value == 1 and defined($value[0]) and $value[0] =~ /\A(\d+|)\z/
                 ) {
                     if ($value[0] && $_ eq $old) {
                         Test::Base::diag("Filters returning numbers are supposed to do munging \$_: your filter '$function' apparently doesn't.");
